# force_absolute_imports
simple tool that ensures that you use only absolute imports

```py
# install
python -m pip install force_absolute_imports

# usage
python -m force_absolute_imports foo.py bar.py folder 
```

Pass python files and/or folders. Folders will recursively scanned for `.py` files
